/**
 * Copyright (C) 2003-2006 Funambol
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

package com.funambol.syncclient.spdm;

/**
 * This is a simple implementation of <i>DeviceManager</i> that uses the file
 * system to store and read nodes.
 * The root of the configuration tree is specified with the system property
 * <code>spdm.dir.config</code>; if null, the current directory is taken.
 * <p>
 * The tree structure is orgnaized in contexts, represented by directories, and
 * leaf nodes, represented by properties files. Leaf nodes contain the
 * configuration values.
 *
 *
 *
 * @version $Id: SimpleDeviceManager.java,v 1.1 2006/01/18 17:09:04 luigiafassina Exp $
 */

public class SimpleDeviceManager extends DeviceManager {

    // --------------------------------------------------------------- Constants

    /**
     * The system property name for the base directory
     */
    public static final String PROP_DM_DIR_BASE = "spdm.dir.base";


    //@todo trovare un altro modo per settare la appURI in relazione al JDBC
    /**
     * The system property name for the application base uri
     */
    //public static final String PROP_DM_APP_BASE = "sp.application.uri";

    // ------------------------------------------------------------ private dara

    private String baseDir = null;

    // ------------------------------------------------------------ Constructors

    /**
     * Creates a new SimpleDeviceManager
     */
    public SimpleDeviceManager() {
        baseDir = System.getProperty(PROP_DM_DIR_BASE, "./");

        //
        // Config dir must end with '/'
        //
        if (!baseDir.endsWith("/")) {
            baseDir += '/';
        }
    }
    //----------------------------------------------------------- Public methods

    /**
     * Factory for SimpleDeviceManager.
     *
     * @return the newly created instance
     */
    public static DeviceManager getDeviceManager(){
        return (DeviceManager) new SimpleDeviceManager();
    }

    /**
     * Return the management tree given its context
     *
     * @param context the node context
     *
     * @return the root management node starting at the specified context
     *
     */
    public ManagementNode getManagementTree(String context){
        return new NodeImpl(null, baseDir + context);
    }

    /**
     * The same as <i>getManagementTree("")</i>
     *
     * @return <i>getManagementTree("")</i>
     */
    public ManagementNode getManagementTree(){
        return getManagementTree("");
    }

    public Device getDevice() {
        return new DeviceImpl(this);
    }

}
